@@ -1,4 +1,4 @@
 __author__ = "Rust Saiargaliev"
-__email__ = "hi@amureki.me"
+__email__ = "amureki@hey.com"
 __url__ = "https://github.com/amureki/statuscheck"
-__version__ = "3.10.0"
+__version__ = "3.11.0"
