@@ -14,8 +14,10 @@ SERVICES = [
     "coveralls",
     "digitalocean",
     "discord",
+    "dnsimple",
     "docker",
     "epicgames",
+    "fastly",
     "gandi",
     "geckoboard",
     "github",
@@ -34,6 +36,7 @@ SERVICES = [
     "redislabs",
     "salesforce",
     "sentry",
+    "sendgrid",
     "servicemax",
     "signal",
     "slack",
